This is a test of internationalization (i18n).

- Romance: üöäÜÖÄ çèé ¿ñ èàùò
  - HTML encoded: &#x00FC;&#x00F6;&#x00E4;&#x00DC;&#x00D6;&#x00C4; &#x00E7;&#x00E8;&#x00E9; &#x00BF;&#x00F1; &#x00E8;&#x00E0;&#x00F9;&#x00F2;
  - URI encoded (UTF-8): %C3%BC%C3%B6%C3%A4%C3%9C%C3%96%C3%84+%C3%A7%C3%A8%C3%A9+%C2%BF%C3%B1+%C3%A8%C3%A0%C3%B9%C3%B2
- Korean: 열에
  - HTML encoded: &#xC5F4;&#xC5D0;
  - URI encoded (UTF-8): %EC%97%B4%EC%97%90
- Chinese: 中文
  - HTML encoded: &#x4E2D;&#x6587;
  - URI encoded (UTF-8): %E4%B8%AD%E6%96%87
- Japanese: まぷ
  - HTML encoded: &#x307E;&#x3077;
  - URI encoded (UTF-8): %E3%81%BE%E3%81%B7
- Dangerous: &%?\+|,%*
- Dangerous Link IDs: veni, vidi, vici, c:\foo\bar, c:\I came, I \saw\, I conquered